/*
 * @(#)FeatureMaker.java	1.1 06/25/04
 *
 * McGill Univarsity
 */

package bodhidharma.midi_parsing;

import	bodhidharma.data_structures.*;
import	bodhidharma.midi_parsing.*;
import	bodhidharma.midi_parsing.one_dimensional_features.*;
import	bodhidharma.midi_parsing.multi_dimensional_features.*;

/**
 * A container class for the <code>makeFeature</code> and\
 * <code>getNumberPossibleFeatures</code> methods.
 *
 * @author	Cory McKay
 * @see		MIDIIntermediateRepresentations
 * @see		FeatureMultiDimensional
 * @see		FeatureOneDimensional
 */
public class FeatureMaker 
{
	/**
	 * Takes in the name of a type of <code>Feature</code> and returns a <code>Feature</code>
	 * object of the appropriate type. The name may also be a numerical code (see implementation).
	 *
	 * <p>Also takes in a <code>MIDIIntermediateRepresentations</code>. If this is null,
	 * then the returned <code>Feature</code> is instantiated without a valid <i>value</i>. If
	 * the value is not null, then the <code>Feature</code> is instantiated with a
	 * <i>value</i> that is derived from the <code>MIDIIntermediateRepresentations</code>.
	 *
	 * @param	feature_name	The name of the type of Feature to be returned.
	 * @param	recording_data	The data upon which the value of the Feature is based.
	 * @return	A Feature object of the appropriate type.
	 * @throws	Exception		Exception thrown if the type of Feature specified is not known.
	 */
	public static Feature makeFeature(String feature_name, MIDIIntermediateRepresentations recording_data)
		throws Exception
	{
			if (feature_name.equals("Pitched Instruments Present") || feature_name.equals("0"))
				return new PitchedInstrumentsPresentFeature(recording_data);
			else if (feature_name.equals("Unpitched Instruments Present") || feature_name.equals("1"))
				return new UnpitchedInstrumentsPresentFeature(recording_data);
			else if (feature_name.equals("Note Prevalence of Pitched Instruments") || feature_name.equals("2"))
				return new NotePrevalenceOfPitchedInstrumentsFeature(recording_data);
			else if (feature_name.equals("Note Prevalence of Unpitched Instruments") || feature_name.equals("3"))
				return new NotePrevalenceOfUnpitchedInstrumentsFeature(recording_data);
			else if (feature_name.equals("Time Prevalence of Pitched Instruments") || feature_name.equals("4"))
				return new TimePrevalenceOfPitchedInstrumentsFeature(recording_data);
			else if (feature_name.equals("Variability of Note Prevalence of Pitched Instruments") || feature_name.equals("5"))
				return new VariabilityOfNotePrevalenceOfPitchedInstrumentsFeature(recording_data);
			else if (feature_name.equals("Variability of Note Prevalence of Unpitched Instruments") || feature_name.equals("6"))
				return new VariabilityOfNotePrevalenceOfUnpitchedInstrumentsFeature(recording_data);
			else if (feature_name.equals("Number of Pitched Instruments") || feature_name.equals("7"))
				return new NumberOfPitchedInstrumentsFeature(recording_data);
			else if (feature_name.equals("Number of Unpitched Instruments") || feature_name.equals("8"))
				return new NumberOfUnpitchedInstrumentsFeature(recording_data);
			else if (feature_name.equals("Percussion Prevalence") || feature_name.equals("9"))
				return new PercussionPrevalenceFeature(recording_data);
			else if (feature_name.equals("String Keyboard Fraction") || feature_name.equals("10"))
				return new StringKeyboardFractionFeature(recording_data);
			else if (feature_name.equals("Acoustic Guitar Fraction") || feature_name.equals("11"))
				return new AcousticGuitarFractionFeature(recording_data);
			else if (feature_name.equals("Electric Guitar Fraction") || feature_name.equals("12"))
				return new ElectricGuitarFractionFeature(recording_data);
			else if (feature_name.equals("Violin Fraction") || feature_name.equals("13"))
				return new ViolinFractionFeature(recording_data);
			else if (feature_name.equals("Saxophone Fraction") || feature_name.equals("14"))
				return new SaxophoneFractionFeature(recording_data);
			else if (feature_name.equals("Brass Fraction") || feature_name.equals("15"))
				return new BrassFractionFeature(recording_data);
			else if (feature_name.equals("Woodwinds Fraction") || feature_name.equals("16"))
				return new WoodwindsFractionFeature(recording_data);
			else if (feature_name.equals("Orchestral Strings Fraction") || feature_name.equals("17"))
				return new OrchestralStringsFractionFeature(recording_data);
			else if (feature_name.equals("String Ensemble Fraction") || feature_name.equals("18"))
				return new StringEnsembleFractionFeature(recording_data);
			else if (feature_name.equals("Electric Instrument Fraction") || feature_name.equals("19"))
				return new ElectricInstrumentFractionFeature(recording_data);
			else if (feature_name.equals("Maximum Number of Independent Voices") || feature_name.equals("20"))
				return new MaximumNumberOfIndependentVoicesFeature(recording_data);
			else if (feature_name.equals("Average Number of Independent Voices") || feature_name.equals("21"))
				return new AverageNumberOfIndependentVoicesFeature(recording_data);
			else if (feature_name.equals("Variability of Number of Independent Voices") || feature_name.equals("22"))
				return new VariabilityOfNumberOfIndependentVoicesFeature(recording_data);
			else if (feature_name.equals("Voice Equality - Number of Notes") || feature_name.equals("23"))
				return new VoiceEqualityNumberOfNotesFeature(recording_data);
			else if (feature_name.equals("Voice Equality - Note Duration") || feature_name.equals("24"))
				return new VoiceEqualityNoteDurationFeature(recording_data);
			else if (feature_name.equals("Voice Equality - Dynamics") || feature_name.equals("25"))
				return new VoiceEqualityDynamicsFeature(recording_data);
			else if (feature_name.equals("Voice Equality - Melodic Leaps") || feature_name.equals("26"))
				return new VoiceEqualityMelodicLeapsFeature(recording_data);
			else if (feature_name.equals("Voice Equality - Range") || feature_name.equals("27"))
				return new VoiceEqualityRangeFeature(recording_data);
			else if (feature_name.equals("Importance of Loudest Voice") || feature_name.equals("28"))
				return new ImportanceOfLoudestVoiceFeature(recording_data);
			else if (feature_name.equals("Relative Range of Loudest Voice") || feature_name.equals("29"))
				return new RelativeRangeOfLoudestVoiceFeature(recording_data);
			else if (feature_name.equals("Range of Highest Line") || feature_name.equals("30"))
				return new RangeOfHighestLineFeature(recording_data);
			else if (feature_name.equals("Relative Note Density of Highest Line") || feature_name.equals("31"))
				return new RelativeNoteDensityOfHighestLineFeature(recording_data);
			else if (feature_name.equals("Melodic Intervals in Lowest Line") || feature_name.equals("32"))
				return new MelodicIntervalsInLowestLineFeature(recording_data);
			else if (feature_name.equals("Voice Separation") || feature_name.equals("33"))
				return new VoiceSeparationFeature(recording_data);
			else if (feature_name.equals("Strongest Rhythmic Pulse") || feature_name.equals("34"))
				return new StrongestRhythmicPulseFeature(recording_data);
			else if (feature_name.equals("Second Strongest Rhythmic Pulse") || feature_name.equals("35"))
				return new SecondStrongestRhythmicPulseFeature(recording_data);
			else if (feature_name.equals("Harmonicity of Two Strongest Rhythmic Pulses") || feature_name.equals("36"))
				return new HarmonicityOfTwoStrongestRhythmicPulsesFeature(recording_data);
			else if (feature_name.equals("Strength of Strongest Rhythmic Pulse") || feature_name.equals("37"))
				return new StrengthOfStrongestRhythmicPulseFeature(recording_data);
			else if (feature_name.equals("Strength of Second Strongest Rhythmic Pulse") || feature_name.equals("38"))
				return new StrengthOfSecondStrongestRhythmicPulseFeature(recording_data);
			else if (feature_name.equals("Strength Ratio of Two Strongest Rhythmic Pulses") || feature_name.equals("39"))
				return new StrengthRatioOfTwoStrongestRhythmicPulsesFeature(recording_data);
			else if (feature_name.equals("Combined Strength of Two Strongest Rhythmic Pulses") || feature_name.equals("40"))
				return new CombinedStrengthOfTwoStrongestRhythmicPulsesFeature(recording_data);
			else if (feature_name.equals("Number of Strong Pulses") || feature_name.equals("41"))
				return new NumberOfStrongPulsesFeature(recording_data);
			else if (feature_name.equals("Number of Moderate Pulses") || feature_name.equals("42"))
				return new NumberOfModeratePulsesFeature(recording_data);
			else if (feature_name.equals("Number of Relatively Strong Pulses") || feature_name.equals("43"))
				return new NumberOfRelativelyStrongPulsesFeature(recording_data);
			else if (feature_name.equals("Rhythmic Looseness") || feature_name.equals("44"))
				return new RhythmicLoosenessFeature(recording_data);
			else if (feature_name.equals("Polyrhythms") || feature_name.equals("45"))
				return new PolyrhythmsFeature(recording_data);
			else if (feature_name.equals("Rhythmic Variability") || feature_name.equals("46"))
				return new RhythmicVariabilityFeature(recording_data);
			else if (feature_name.equals("Beat Histogram") || feature_name.equals("47"))
				return new BeatHistogramFeature(recording_data);
			else if (feature_name.equals("Note Density") || feature_name.equals("48"))
				return new NoteDensityFeature(recording_data);
			else if (feature_name.equals("Average Note Duration") || feature_name.equals("49"))
				return new AverageNoteDurationFeature(recording_data);
			else if (feature_name.equals("Variability of Note Duration") || feature_name.equals("50"))
				return new VariabilityOfNoteDurationFeature(recording_data);
			else if (feature_name.equals("Maximum Note Duration") || feature_name.equals("51"))
				return new MaximumNoteDurationFeature(recording_data);
			else if (feature_name.equals("Minimum Note Duration") || feature_name.equals("52"))
				return new MinimumNoteDurationFeature(recording_data);
			else if (feature_name.equals("Staccato Incidence") || feature_name.equals("53"))
				return new StaccatoIncidenceFeature(recording_data);
			else if (feature_name.equals("Average Time Between Attacks") || feature_name.equals("54"))
				return new AverageTimeBetweenAttacksFeature(recording_data);
			else if (feature_name.equals("Variability of Time Between Attacks") || feature_name.equals("55"))
				return new VariabilityOfTimeBetweenAttacksFeature(recording_data);
			else if (feature_name.equals("Average Time Between Attacks For Each Voice") || feature_name.equals("56"))
				return new AverageTimeBetweenAttacksForEachVoiceFeature(recording_data);
			else if (feature_name.equals("Average Variability of Time Between Attacks For Each Voice") || feature_name.equals("57"))
				return new AverageVariabilityOfTimeBetweenAttacksForEachVoiceFeature(recording_data);
			else if (feature_name.equals("Initial Tempo") || feature_name.equals("58"))
				return new InitialTempoFeature(recording_data);
			else if (feature_name.equals("Initial Time Signature") || feature_name.equals("59"))
				return new InitialTimeSignatureFeature(recording_data);
			else if (feature_name.equals("Compound Or Simple Meter") || feature_name.equals("60"))
				return new CompoundOrSimpleMeterFeature(recording_data);
			else if (feature_name.equals("Triple Meter") || feature_name.equals("61"))
				return new TripleMeterFeature(recording_data);
			else if (feature_name.equals("Quintuple Meter") || feature_name.equals("62"))
				return new QuintupleMeterFeature(recording_data);
			else if (feature_name.equals("Changes of Meter") || feature_name.equals("63"))
				return new ChangesOfMeterFeature(recording_data);
			else if (feature_name.equals("Overall Dynamic Range") || feature_name.equals("64"))
				return new OverallDynamicRangeFeature(recording_data);
			else if (feature_name.equals("Variation of Dynamics") || feature_name.equals("65"))
				return new VariationOfDynamicsFeature(recording_data);
			else if (feature_name.equals("Variation of Dynamics In Each Voice") || feature_name.equals("66"))
				return new VariationOfDynamicsInEachVoiceFeature(recording_data);
			else if (feature_name.equals("Average Note To Note Dynamics Change") || feature_name.equals("67"))
				return new AverageNoteToNoteDynamicsChangeFeature(recording_data);
			else if (feature_name.equals("Most Common Pitch Prevalence") || feature_name.equals("68"))
				return new MostCommonPitchPrevalenceFeature(recording_data);
			else if (feature_name.equals("Most Common Pitch Class Prevalence") || feature_name.equals("69"))
				return new MostCommonPitchClassPrevalenceFeature(recording_data);
			else if (feature_name.equals("Relative Strength of Top Pitches") || feature_name.equals("70"))
				return new RelativeStrengthOfTopPitchesFeature(recording_data);
			else if (feature_name.equals("Relative Strength of Top Pitch Classes") || feature_name.equals("71"))
				return new RelativeStrengthOfTopPitchClassesFeature(recording_data);
			else if (feature_name.equals("Interval Between Strongest Pitches") || feature_name.equals("72"))
				return new IntervalBetweenStrongestPitchesFeature(recording_data);
			else if (feature_name.equals("Interval Between Strongest Pitch Classes") || feature_name.equals("73"))
				return new IntervalBetweenStrongestPitchClassesFeature(recording_data);
			else if (feature_name.equals("Number of Common Pitches") || feature_name.equals("74"))
				return new NumberOfCommonPitchesFeature(recording_data);
			else if (feature_name.equals("Pitch Variety") || feature_name.equals("75"))
				return new PitchVarietyFeature(recording_data);
			else if (feature_name.equals("Pitch Class Variety") || feature_name.equals("76"))
				return new PitchClassVarietyFeature(recording_data);
			else if (feature_name.equals("Range") || feature_name.equals("77"))
				return new RangeFeature(recording_data);
			else if (feature_name.equals("Most Common Pitch") || feature_name.equals("78"))
				return new MostCommonPitchFeature(recording_data);
			else if (feature_name.equals("Primary Register") || feature_name.equals("79"))
				return new PrimaryRegisterFeature(recording_data);
			else if (feature_name.equals("Importance of Bass Register") || feature_name.equals("80"))
				return new ImportanceOfBassRegisterFeature(recording_data);
			else if (feature_name.equals("Importance of Middle Register") || feature_name.equals("81"))
				return new ImportanceOfMiddleRegisterFeature(recording_data);
			else if (feature_name.equals("Importance of High Register") || feature_name.equals("82"))
				return new ImportanceOfHighRegisterFeature(recording_data);
			else if (feature_name.equals("Most Common Pitch Class") || feature_name.equals("83"))
				return new MostCommonPitchClassFeature(recording_data);
			else if (feature_name.equals("Dominant Spread") || feature_name.equals("84"))
				return new DominantSpreadFeature(recording_data);
			else if (feature_name.equals("Strong Tonal Centres") || feature_name.equals("85"))
				return new StrongTonalCentresFeature(recording_data);
			else if (feature_name.equals("Basic Pitch Histogram") || feature_name.equals("86"))
				return new BasicPitchHistogramFeature(recording_data);
			else if (feature_name.equals("Pitch Class Distribution") || feature_name.equals("87"))
				return new PitchClassDistributionFeature(recording_data);
			else if (feature_name.equals("Fifths Pitch Histogram") || feature_name.equals("88"))
				return new FifthsPitchHistogramFeature(recording_data);
			else if (feature_name.equals("Quality") || feature_name.equals("89"))
				return new QualityFeature(recording_data);
			else if (feature_name.equals("Glissando Prevalence") || feature_name.equals("90"))
				return new GlissandoPrevalenceFeature(recording_data);
			else if (feature_name.equals("Average Range of Glissandos") || feature_name.equals("91"))
				return new AverageRangeOfGlissandosFeature(recording_data);
			else if (feature_name.equals("Vibrato Prevalence") || feature_name.equals("92"))
				return new VibratoPrevalenceFeature(recording_data);
			else if (feature_name.equals("Melodic Interval Histogram") || feature_name.equals("93"))
				return new MelodicIntervalHistogramFeature(recording_data);
			else if (feature_name.equals("Average Melodic Interval") || feature_name.equals("94"))
				return new AverageMelodicIntervalFeature(recording_data);
			else if (feature_name.equals("Most Common Melodic Interval") || feature_name.equals("95"))
				return new MostCommonMelodicIntervalFeature(recording_data);
			else if (feature_name.equals("Distance Between Most Common Melodic Intervals") || feature_name.equals("96"))
				return new DistanceBetweenMostCommonMelodicIntervalsFeature(recording_data);
			else if (feature_name.equals("Most Common Melodic Interval Prevalence") || feature_name.equals("97"))
				return new MostCommonMelodicIntervalPrevalenceFeature(recording_data);
			else if (feature_name.equals("Relative Strength of Most Common Intervals") || feature_name.equals("98"))
				return new RelativeStrengthOfMostCommonIntervalsFeature(recording_data);
			else if (feature_name.equals("Number of Common Melodic Intervals") || feature_name.equals("99"))
				return new NumberOfCommonMelodicIntervalsFeature(recording_data);
			else if (feature_name.equals("Amount of Arpeggiation") || feature_name.equals("100"))
				return new AmountOfArpeggiationFeature(recording_data);
			else if (feature_name.equals("Repeated Notes") || feature_name.equals("101"))
				return new RepeatedNotesFeature(recording_data);
			else if (feature_name.equals("Chromatic Motion") || feature_name.equals("102"))
				return new ChromaticMotionFeature(recording_data);
			else if (feature_name.equals("Stepwise Motion") || feature_name.equals("103"))
				return new StepwiseMotionFeature(recording_data);
			else if (feature_name.equals("Melodic Thirds") || feature_name.equals("104"))
				return new MelodicThirdsFeature(recording_data);
			else if (feature_name.equals("Melodic Fifths") || feature_name.equals("105"))
				return new MelodicFifthsFeature(recording_data);
			else if (feature_name.equals("Melodic Tritones") || feature_name.equals("106"))
				return new MelodicTritonesFeature(recording_data);
			else if (feature_name.equals("Melodic Octaves") || feature_name.equals("107"))
				return new MelodicOctavesFeature(recording_data);
			else if (feature_name.equals("Direction of Motion") || feature_name.equals("108"))
				return new DirectionOfMotionFeature(recording_data);
			else if (feature_name.equals("Duration of Melodic Arcs") || feature_name.equals("109"))
				return new DurationOfMelodicArcsFeature(recording_data);
			else if (feature_name.equals("Size of Melodic Arcs") || feature_name.equals("110"))
				return new SizeOfMelodicArcsFeature(recording_data);
			else
				throw new Exception("Unknwon feature name encountered: " + feature_name + ".");
	}


	/**
	 * Returns the number of different types of features which have been implemented.
	 */
	public static int getNumberPossibleFeatures()
	{
		return 111;
	}
}