/*
 * @(#)BeatHistogramFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package	bodhidharma.midi_parsing.multi_dimensional_features;

import  bodhidharma.midi_parsing.*;

/**
 * Each object of this class calculates the value of a single multi-dimensional feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the values of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class BeatHistogramFeature
	extends FeatureMultiDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to null if the parameter is null.
	 */
	public BeatHistogramFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			value = new double[recording_info.rhythmic_histogram.length - 40];
			for (int i = 0; i < value.length; i++)
				value[i] = recording_info.rhythmic_histogram[i + 40];
		}

		else value = null;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Beat Histogram");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("A feature array with entries corresponding to the frequency values of\n" +
		                  "each of the bins of the beat histogram (except the first 40 empty ones).");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("R-14");
	}
}