/*
 * @(#)InitialTimeSignatureFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package	bodhidharma.midi_parsing.multi_dimensional_features;

import  bodhidharma.midi_parsing.*;
import java.util.LinkedList;

/**
 * Each object of this class calculates the value of a single multi-dimensional feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the values of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class InitialTimeSignatureFeature
	extends FeatureMultiDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to null if the parameter is null.
	 */
	public InitialTimeSignatureFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			value = new double[2];

			if (((LinkedList) recording_info.meta_data[1]).size() == 0)
			{
				value[0] = 0.0;
				value[1] = 0.0;
			}

			else
			{
				Object[] numerators_objects = ((LinkedList) recording_info.meta_data[1]).toArray();
				double[] numerators = new double[numerators_objects.length];
				for (int i = 0; i < numerators.length; i++)
					numerators[i] = ((Integer) numerators_objects[i]).doubleValue();
				Object[] denominators_objects = ((LinkedList) recording_info.meta_data[2]).toArray();
				double[] denominators = new double[denominators_objects.length];
				for (int i = 0; i < denominators.length; i++)
					denominators[i] = ((Integer) denominators_objects[i]).doubleValue();

				value[0] = numerators[0];
				value[1] = denominators[0];
			}
		}

		else value = null;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Initial Time Signature");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("A feature array with two elements. The first is the numerator\n" +
		                  "of the first occurring time signature and the second is the\n" +
		                  "denominator of the first occurring time signature. Both are set\n" +
		                  "to 0 if no time signature is present.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("R-31");
	}
}