/*
 * @(#)MelodicIntervalHistogramFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package	bodhidharma.midi_parsing.multi_dimensional_features;

import  bodhidharma.midi_parsing.*;

/**
 * Each object of this class calculates the value of a single multi-dimensional feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the values of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class MelodicIntervalHistogramFeature
	extends FeatureMultiDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to null if the parameter is null.
	 */
	public MelodicIntervalHistogramFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			value = new double[recording_info.melodic_histogram.length];
			for (int pitch = 0; pitch < value.length; pitch++)
				value[pitch] = recording_info.melodic_histogram[pitch];
		}

		else value = null;
	}

	
	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Melodic Interval Histogram");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("A features array with bins corresponding to the values of the\n" +
		                  "melodic interval histogram.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("M-1");
	}
}