/*
 * @(#)NotePrevalenceOfUnpitchedInstrumentsFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package	bodhidharma.midi_parsing.multi_dimensional_features;

import  bodhidharma.midi_parsing.*;

/**
 * Each object of this class calculates the value of a single multi-dimensional feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the values of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class NotePrevalenceOfUnpitchedInstrumentsFeature
	extends FeatureMultiDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to null if the parameter is null.
	 */
	public NotePrevalenceOfUnpitchedInstrumentsFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			value = new double[47];

			for (int instrument = 35; instrument < 82; instrument++)
				value[instrument - 35] = recording_info.non_pitched_instrumentation_frequencies[instrument] /
				                    (double) recording_info.total_number_notes;
		}

		else value = null;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Note Prevalence of Unpitched Instruments");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("The fraction of (unpitched) notes played by each General MIDI Percussion\n" +
		                  "Key Map Instrument. There is one entry for each instrument, which is set\n" +
		                  "to the number of Note Ons played using the corresponding MIDI note\n" +
		                  "value divided by the total number of Note Ons in the recording.\n" +
		                  "\nIt should be noted that only instruments 35 to 81 are\n" +
		                  "included here, as they are the ones that meet the official\n" +
		                  "standard. They are numbered in this array from 0 to 46.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("I-4");
	}
}