/*
 * @(#)PitchClassDistributionFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package	bodhidharma.midi_parsing.multi_dimensional_features;

import  bodhidharma.midi_parsing.*;

/**
 * Each object of this class calculates the value of a single multi-dimensional feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the values of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class PitchClassDistributionFeature
	extends FeatureMultiDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to null if the parameter is null.
	 */
	public PitchClassDistributionFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Find index of largest
			int index = bodhidharma.utilities.Statistics.getIndexOfLargest(recording_info.pitch_class_histogram);
			
			// Construct new histogram starting with largest
			value = new double[recording_info.pitch_class_histogram.length];
			for (int i = 0; i < value.length; i++)
			{
				value[i] = recording_info.pitch_class_histogram[index];
				index++;

				// Wrap around
				if (index == value.length)
					index = 0;
			}
		}

		else value = null;
	}

	
	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Pitch Class Distribution");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("A feature array with 12 entries where the first holds the\n" +
		                  "frequency of the bin of the pitch class histogram with the\n" +
		                  "highest frequency, and the following entries holding the\n" +
		                  "successive bins of the histogram, wrapping around if necessary.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("P-20");
	}
}