/*
 * @(#)TimePrevalenceOfPitchedInstrumentsFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package	bodhidharma.midi_parsing.multi_dimensional_features;

import  bodhidharma.midi_parsing.*;

/**
 * Each object of this class calculates the value of a single multi-dimensional feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the values of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class TimePrevalenceOfPitchedInstrumentsFeature
	extends FeatureMultiDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to null if the parameter is null.
	 */
	public TimePrevalenceOfPitchedInstrumentsFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			value = new double[128];

			for (int instrument = 0; instrument < value.length; instrument++)
				value[instrument] = recording_info.pitched_instrumentation_frequencies[instrument][1] /
				                    (double) recording_info.recording_length;
		}

		else value = null;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Time Prevalence of Pitched Instruments");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("The fraction of the total time of the recording in which a note was\n" +
		                  "sounding for each (pitched) General MIDI Instrument.\n" +
		                  "There is one entry for each instrument, which is set to the total\n" +
		                  "time in seconds during which a given instrument was sounding one\n" +
		                  "or more notes divided by the total length in seconds of the piece.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("I-5");
	}
}