/*
 * @(#)AmountOfArpeggiationFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class AmountOfArpeggiationFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public AmountOfArpeggiationFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Calculate the value
			value = recording_info.melodic_histogram[0] +
			        recording_info.melodic_histogram[3] +
			        recording_info.melodic_histogram[4] +
			        recording_info.melodic_histogram[7] +
			        recording_info.melodic_histogram[10] +
			        recording_info.melodic_histogram[11] +
			        recording_info.melodic_histogram[12] +
			        recording_info.melodic_histogram[15] +
			        recording_info.melodic_histogram[16];
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Amount of Arpeggiation");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Fraction of horizontal intervals that are repeated notes, minor\n" +
		                  "thirds, major thirds, perfect fifths, minor sevenths, major sevenths,\n" +
		                  "octaves, minor tenths or major tenths.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("M-8");
	}
}