/*
 * @(#)AverageTimeBetweenAttacksFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class AverageTimeBetweenAttacksFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public AverageTimeBetweenAttacksFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			double total_of_intervals = 0;
			int number_of_intervals = 0;

			double time_so_far = 0.0;
			int tick_of_last_attack  = -1;
			for (int tick = 0; tick < recording_info.note_beginnings_map.length; tick++)
			{
				// Check if an attack occured on this tick
				boolean attack = false;
				for (int chan = 0; chan < 16; chan++)
				{
					if (recording_info.note_beginnings_map[tick][chan])
					{
						attack = true;
						chan = 17; // exit the loop
					}
				}
				
				if (!attack)
					time_so_far += recording_info.seconds_per_tick[tick];
				else
				{
					if (tick_of_last_attack != -1)
					{
						total_of_intervals += time_so_far;
						number_of_intervals++;
					}

					time_so_far = 0.0;
					tick_of_last_attack = tick;
				}
			}

			value = total_of_intervals / (double) number_of_intervals;
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Average Time Between Attacks");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Average time in seconds between Note On events\n" +
		                  "(irregardless of channel).");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("R-22");
	}
}