/*
 * @(#)CompoundOrSimpleMeterFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma.midi_parsing.*;
import java.util.LinkedList;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class CompoundOrSimpleMeterFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public CompoundOrSimpleMeterFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Default to simple
			value = 0.0;

			// If time signature specified
			if (((LinkedList) recording_info.meta_data[1]).size() != 0)
			{
				// Convert data types
				Object[] numerators_objects = ((LinkedList) recording_info.meta_data[1]).toArray();
				int[] numerators = new int[numerators_objects.length];
				for (int i = 0; i < numerators.length; i++)
					numerators[i] = ((Integer) numerators_objects[i]).intValue();
				
				// Find initial numerator
				int num = numerators[0];

				// Find if compound
				if (num >= 6 && (num % 3) == 0)
					value = 1.0;
			}
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Compound Or Simple Meter");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Set to 1 if the initial meter is compound (numerator of time\n" +
		                  "signature is greater than or equal to 6 and is evenly divisible\n" +
		                  "by 3) and to 0 if it is simple (if the above condition is not fulfilled).");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("R-32");
	}
}