/*
 * @(#)MelodicOctavesFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class MelodicOctavesFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public MelodicOctavesFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Calculate the value
			value = recording_info.melodic_histogram[12];
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Melodic Octaves");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Fraction of melodic intervals that are octaves.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("M-15");
	}
}