/*
 * @(#)OverallDynamicRangeFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class OverallDynamicRangeFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public OverallDynamicRangeFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			int max = 0;
			int min = 127;
			for (int i = 0; i < recording_info.note_loudnesses.length; i++)
				for (int j = 0; j < recording_info.note_loudnesses[i].length; j++)
				{
					if (recording_info.note_loudnesses[i][j] > max)
						max = recording_info.note_loudnesses[i][j];
					if (recording_info.note_loudnesses[i][j] < min)
						min = recording_info.note_loudnesses[i][j];
				}
			
			value = ((double) (max - min));
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Overall Dynamic Range");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("The maximum loudness minus the minimum loudness value.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("D-1");
	}
}