/*
 * @(#)StrengthRatioOfTwoStrongestRhythmicPulsesFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class StrengthRatioOfTwoStrongestRhythmicPulsesFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public StrengthRatioOfTwoStrongestRhythmicPulsesFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Find the highest bin
			double max = 0.0;
			int max_index = 0;
			for (int bin = 0; bin < recording_info.rhythmic_histogram.length; bin++)
				if (recording_info.rhythmic_histogram[bin] > max)
				{
					max = recording_info.rhythmic_histogram[bin];
					max_index = bin;
				}
			
			// Find the second highest bin
			double second_highest = 0.0;
			int second_hidhest_index = 0;
			for (int bin = 0; bin < recording_info.rhythmic_histogram_table.length; bin++)
				if (recording_info.rhythmic_histogram_table[bin][1] > second_highest && bin != max_index)
				{
					second_highest = recording_info.rhythmic_histogram_table[bin][1];
					second_hidhest_index = bin;
				}

			// Calculate the value
			if (max > second_highest)
				value = max_index / second_highest;
			else
				value = second_highest / max_index;
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Strength Ratio of Two Strongest Rhythmic Pulses");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("The frequency of the higher (in terms of frequency) of the two beat\n" +
		                  "bins corresponding to the peaks with the highest frequency divided by\n" +
		                  "the frequency of the lower.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("R-6");
	}
}