/*
 * @(#)StrongTonalCentresFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class StrongTonalCentresFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public StrongTonalCentresFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Check all peaks
			int peaks = 0;
			for (int bin = 0; bin < recording_info.fifths_pitch_histogram.length; bin++)
			{
				if (recording_info.fifths_pitch_histogram[bin] >= 0.09)
				{
					int left = bin - 1;;
					int right = bin + 1;

					// Account for wrap around
					if (right == recording_info.fifths_pitch_histogram.length)
						right = 0;
					if (left == -1)
						left = recording_info.fifths_pitch_histogram.length - 1;

					// Check if is a peak
					if ( recording_info.fifths_pitch_histogram[bin] > recording_info.fifths_pitch_histogram[left] &&
					     recording_info.fifths_pitch_histogram[bin] > recording_info.fifths_pitch_histogram[right] )
						peaks++;
				}
			}

			// Calculate the value
			value = (double) peaks;
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Strong Tonal Centres");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Number of peaks in the fifths pitch histogram that each account\n" +
		                  "for at least 9% of all Note Ons.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("P-18");
	}
}