/*
 * @(#)FileFilterRecordings.java	1.1 06/25/04
 *
 * McGill University
 */

package bodhidharma.utilities;

import java.io.File;
import javax.swing.filechooser.FileFilter;

/**
 * A file filter for the <code>RecordingsPanel</code> class.
 * Implements the two methods of the <code>FileFilter</code>
 * abstract class.
 *
 * <p>Filters all files and directories except MIDI files
 * (ending with .mid or .midi) that are not already parsed
 * by the <code>RecordingsPanel</code>. Directories are only
 * allowed if no recordings are currently loaded (i.e. the
 * constructor parameter <code>already_loaded_file_paths</code>
 * is null.
 * 
 * @author	Cory McKay
 * @see		FileFilter
 * @see		RecordingsPanel
 */
public class FileFilterRecordings
	extends FileFilter
{
	private String[] file_paths_to_reject;


	/**
	 * Intantiates the filter and stores the names of files that have
	 * already been loaded
	 * 
	 * @author	Cory McKay
	 * @param	already_loaded_file_names	Names of files that are alreading loaded in the <code>RecordingsPanel</code>.
	 * @see		RecordingsPanel
	 */
	public FileFilterRecordings(String[] already_loaded_file_paths)
	{
		super();
		file_paths_to_reject = already_loaded_file_paths;
	}


	public boolean accept(File f)
	{
		String filepath = f.getAbsolutePath();
		
		// If no files are loaded, display directories and MIDI files
		if (file_paths_to_reject == null)
		{
			if (f.isDirectory())
				return true;
			else if (filepath.toLowerCase().endsWith(".mid") ||
		             filepath.toLowerCase().endsWith(".midi"))
				return true;
			else
				return false;
		}

		// If files are loaded, display only MIDI files that are not
		// already loaded
		if (filepath.toLowerCase().endsWith(".mid") ||
		    filepath.toLowerCase().endsWith(".midi"))
		{
			boolean filepath_there = false;
			for (int i = 0; i < file_paths_to_reject.length; i++)
				if (file_paths_to_reject[i].equals(filepath))
					filepath_there = true;
			if (filepath_there)
				return false;
			else
				return true;
		}
		else
			return false;
	}


	public String getDescription()
	{
		return "MIDI files that are not already loaded";
	}
}
