/*
 * @(#)ParseProjectFileHandler.java	1.1 06/25/04
 *
 * McGill Univarsity
 */


package bodhidharma.xml_parsing;

import org.xml.sax.*;


/**
 * An extension of the <i>Xerces</i> <code>XML DefaultHandler</code>
 * class that implements the <i>SAX</i> <code>ContentHandler</code>.
 * The methods of this class are called by an instance of an 
 * <code>XMLReader</code> while it is parsing an XML document.
 *
 * <p>This particular implementation is custom designed to parse
 * XML files of the <i>project_file</i> type used by the Bodhidharma
 * music classification system. A custom exceptions is thrown 
 * if the file is not of this type. At the end of parsing,
 * the contents of the file elements are stored in the
 * <i>parsed_file_contents</i> field.
 *
 * @author Cory McKay
 * @see ParseFileHandler
 * @see	Bodhidharma
 * @see XMLDocumentParser
 * @see DefaultHandler
 * @see ContentHandler
 * @see XMLReader
 */
public class ParseProjectFileHandler extends ParseFileHandler
{
	/* FIELDS ******************************************************************/


	/* NOTE: String[] parsed_file_contents:
	 * Holds the data extracted from the project file XML file.
	 * The data is stored in this order: project_comments, project_path,
	 * taxonomy_path, features_path, classifiers_path,
	 * recordings_list_path, preferences_path and current_directory.
	 */
	
	// Counts how many elements have been encountered and read
	private int count;


	/* PUBLIC METHODS **********************************************************/


	/**
	 * This method is called when the start of the XML file to be
	 * parsed is reached. Initializes the parsed_file_contents
	 * field to an array of empty strings and initializes the
	 * count to 0.
	 */
	public void startDocument()
	{
		parsed_file_contents = new String[8];
		for (int i = 0; i < 8; i++)
			parsed_file_contents[i] = new String("");;
		count = 0;
	}

	/**
	 * This method is called when the start of an XML element
	 * is encountered. Increments the count when this occurs.
	 *
	 * @param	name			Name of the element that is encountered.
	 * @throws	SAXException	Exception thrown if is wrong type of XML file.
	 */
	public void startElement(String namespace, String name, String qName, Attributes atts)
		throws SAXException
	{
		if (count == 0)
			if (!name.equals("project_file"))
				throw new SAXException("\n\nIt is in reality of the type " + name + ".");
		count++;
	}

	/**
	 * This stores the contents of elements in the appropriate
	 * element of the parsed_file_contents array.
	 */
	public void characters(char[] ch, int start, int length)
	{
		int i = count - 2;
		if (i >= 0)
			parsed_file_contents[i] = new String(ch, start, length);
	}
}


