/*
 * @(#)HiddenNode.java	1.1 06/25/04
 *
 * McGill University
 */

package bodhidharma.classifiers.feedforward_neural_networks;

/**
 * Objects of this class represent the hidden nodes of a neural network. 
 * OutputNodes can update themselves during learning. Adjustable learning
 * rates and momentums are permitted.
 * 
 * @author Cory McKay
 */
public class HiddenNode
	extends OutputNode
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Instantiate the HiddenNode with the given parameters. inputs includes the bias node,
	 * which is the last one
	 */
	public HiddenNode(double n, double alpha, int inputs) // inputs includes the bias node, which is the last one
	{
		super(n, alpha, inputs);
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 *  Updates the weights of the node during a training iteration
	 */
	public void update_weights(double sum)
	{
		double old_weight; // the weight of a link prior to updating. Used to calculate the change in weight for
		                   // the momentum term

		calculate_error_signal(sum);

		for (int i = 0; i < number_inputs; i++)
		{
			old_weight = weights[i];
			weights[i] = weights[i] + learning_rate * error_signal * input_values[i] + momentum * previous_update[i];
			previous_update[i] = weights[i] - old_weight;
		}
	}


	/* PRIVATE METHODS *********************************************************/


	private void calculate_error_signal(double sum)
	// Calculates the error signal for the hidden node given the information about the next layer of nodes
	{
		error_signal = current_value * (1 - current_value) * sum;
	}
}