/*
 * @(#)Evaluator.java	1.1 06/25/04
 *
 * McGill University
 */

package bodhidharma.classifiers.genetic_algorithms;

/**
 * Objects of this class evaluate and interpret the meaning of bit strings stored in
 * genetic algorithm <code>Chromosome</code> objects. Although <code>Chromosome</code>
 * and <code>Breeder</code> objects are general purpose, <code>Evaluator</code> objects
 * have a specialized purpose.
 *
 * All classes implementing this interface should include a constructor that sets
 * the number of bits in a bit string.
 *
 * @see	Chromosome
 * @see Breeder
 */
public abstract class Evaluator
{
	/* FIELDS ******************************************************************/


	protected int bit_string_length;	// number of bits held in the bit string of any Chromosome


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Return the fitness of a chromosome given its DNA (bit string). The fitness
	 * should vary between 0 (least fit possible) and 1 (most fit possible). This
	 * need not be normalized. Bit strings passed to this method must be
	 * of the same length as the length specified in the constructor of this
	 * object.
	 */
	public abstract double getFitness(short[] bit_string) throws Exception;


	/**
	 * Returns an array of Objects holding the meaning of the given bit string
	 * of a <code>Chromosome</code>. Bit strings passed to this method must be
	 * of the same length as the length specified in the constructor of this
	 * object.
	 */
	public abstract Object[] parseBitString(short[] bit_string) throws Exception;


	/**
	 * Returns the number of bits held in the bit string of any <code>Chromosome</code> that
	 * could be fed to this <code>Evaluator</code> object.
	 */
	public int getBitStringLength()
	{
		return bit_string_length;
	}
}