/*
 * @(#)Feature.java	1.1 06/25/04
 *
 * McGill University
 */

package bodhidharma.data_structures;

import  midi_parsing.*;

/**
 * An abstract class for holding a feature. Each class implementing this
 * abstract class should hold the value of a single feature that is
 * extracted from a recording.
 *
 * <p>The constructor of a class implementing this interface should
 * take in an intermediate representation of a recording and derive
 * the value of the feature from this. There should also be a constructor
 * with no arguments that initializes the value of the feature to null or -1.0.
 *
 * <p>Classes implementing this class should also have a getValue() method
 * that returns the value of the feature (using whatever datatype is
 * appropriate).
 * 
 * @author Cory McKay
 */
public abstract class Feature
{
	/**
	 * Returns the name of the feature.
	 */
	public	abstract	String	getName();

	/**
	 * Returns a sentence or two describing the feature.
	 */
	public	abstract	String	getDescription();

	/**
	 * Returns the code number of the feature.
	 */
	public	abstract	String	getCode();
}