/*
 * @(#)FeatureSettings.java	1.1 06/25/04
 *
 * McGill Univarsity
 */

package bodhidharma.data_structures;

import bodhidharma.midi_parsing.one_dimensional_features.*;

/**
 * Part of the Bodhidharma automatic music classification
 * project. Holds the data relating to how an individual
 * feature is to be used.
 *
 * @author Cory McKay
 * @see	FeaturessPanel
 * @see Feature
 * @see FeatureSet
 */
public class  FeatureSettings
{
	/* FIELDS ******************************************************************/

	/**
	 * A dummy feature of the type whose settings are defined with this
	 * <code>FeatureSettings</code> object.
	 */
	private	Feature		feature;
	
	/**
	 * Whether or not the feature should be extracted
	 */
	public	boolean		extract_feature;
	
	/**
	 * Whether or not the feature is a candidate for feature selection
	 */
	public	boolean		candidate_feature;
	
	/**
	 * Whether or not the feature is to be used if a classification is
	 * performed in overide mode (without automatic feature selection).
	 */
	public	boolean		overide_feature;
	
	/**
	 * Whether or not the feature has only one value.
	 */
	public	boolean		one_dimensional_feature;
	

	/* CONSTRUCTORS ************************************************************/


	/**
	 * Basic constructor that fills in the fields directly with no alterations.
	 * dummy_feature is a feature with no value but of the correct type.
	 */
	public FeatureSettings(Feature dummy_feature, boolean extract, boolean candidate, boolean overide)
	{
		// Set fields based on parameters
		feature = dummy_feature;
		extract_feature = extract;
		candidate_feature = candidate;
		overide_feature = overide;

		// Set the value of one_dimensional_feature based on dummy_feature
		if (dummy_feature instanceof FeatureOneDimensional)
			one_dimensional_feature = true;
		else
			one_dimensional_feature = false;
	}


	/**
	 * Basic constructor that sets feature to null and all other fields to defaults
	 * (all true except overide_feature, which is false).
	 */
	public FeatureSettings()
	{
		feature = null;
		extract_feature = true;
		candidate_feature = true;
		overide_feature = false;
		one_dimensional_feature = true;
	}



	/* PUBLIC METHODS **********************************************************/


	/**
	 * Sets the <i>feature</i> field based on the given parameter.
	 *
	 * @param	dummy_feature	The dummy feature to be stored.
	 */
	public void setFeature(Feature dummy_feature)
	{
		feature = dummy_feature;

		// Set the value of one_dimensional_feature based on dummy_feature
		if (dummy_feature instanceof FeatureOneDimensional)
			one_dimensional_feature = true;
		else
			one_dimensional_feature = false;
	}


	/**
	 * Returns the dummy feature stored in the <i>feature</i> field.
	 *
	 * @return	The dummy feature stored in the <i>feature</i> field.
	 */
	public Feature getFeature()
	{
		return feature;
	}
}
