/*
 * @(#)Recording.java	1.1 06/25/04
 *
 * McGill Univarsity
 */

package bodhidharma.data_structures;

/**
 * Part of the Bodhidharma automatic music classification
 * project. Holds the meta-data relating to a recording.
 *
 * <p>Holds identification informations for the recording
 * as well as what is to be done with it and any features
 * that have been extracted from it.
 *
 * @author Cory McKay
 * @see	RecordingsPanel
 * @see ParseRecordingsFileHandler
 * @see FeatureSet
 */
public class  Recording
{
	/* FIELDS ******************************************************************/

	/**
	 * The title of the recording
	 */
	public	String		title;
	
	/**
	 * The artist (performer or composer) asociated with the recording
	 */
	public	String		artist;
	
	/**
	 * The file_path of the recording
	 */
	public	String		file_path;
	
	/**
	 * The names of all leaf categories associated with the recording
	 */
	public	String[]	leaf_categories;
	
	/**
	 * The names of all ancestors of the leaf categories based on the
	 * taxonomy in memory when the recording was processed
	 */
	public	String[]	ancestor_categories;
	
	/**
	 * Whether or not to use this recording as a training piece during
	 * classifier training
	 */
	public	boolean		use_for_training;
	
	/**
	 * Whether or not to use this recording a testing piece during
	 * classifier training
	 */
	public	boolean		use_for_testing;
	
	/**
	 * Whether or not this piece is to be classified during the next
	 * classification operation
	 */
	public	boolean		use_for_classification;

	/**
	 * The values of the features that have been extracted from this
	 * recording
	 */
	public	FeatureSet	feature_set;


	/* CONSTRUCTORS ************************************************************/


	/**
	 * Basic constructor that fills in the fields directly with no alterations.
	 */
	public Recording(String	recording_title, String	recording_artist, String recording_file_path,
	                 String[] recording_leaf_categories, String[] recording_ancestor_categories,
	                 boolean use_recording_for_training, boolean use_recording_for_testing,
	                 boolean use_recording_for_classification, FeatureSet recording_feature_set)
	{
		title = recording_title;
		artist = recording_artist;
		file_path = recording_file_path;
		leaf_categories = recording_leaf_categories;
		ancestor_categories = recording_ancestor_categories;
		use_for_training = use_recording_for_training;
		use_for_testing = use_recording_for_testing;
		use_for_classification = use_recording_for_classification;
		feature_set = recording_feature_set;
	}

	/**
	 * Basic constructor that sets all fields to null (of false for booleans).
	 */
	public Recording()
	{
		title = null;
		artist = null;
		file_path = null;
		leaf_categories = null;
		ancestor_categories = null;
		use_for_training = false;
		use_for_testing = false;
		use_for_classification = false;
		feature_set = null;
	}
}
