/*
 * @(#)FeatureMultiDimensional.java	1.0 01/06/04
 *
 * McGill University
 */

package	bodhidharma.midi_parsing.multi_dimensional_features;

import  bodhidharma.data_structures.*;

/**
 * An abstract class for holding a feature with a multiple values.
 * Each class implementing this abstract class will hold the
 * value of a single feature that is extracted from a recording.
 *
 * <p>The <code>getValue</code> method returns the values of the feature
 * and the <code>getValue</code> method sets them. 
 *
 * <p>The constructor of a class implementing this interface should
 * take in an intermediate representation of a recording and derive
 * the value of the feature from this. If the second argument of the constructor
 * is null, then the object should be initialized so that the value of the feature
 * is null.
 * 
 * @author	Cory McKay
 * @see		Feature
 */
public abstract class FeatureMultiDimensional
	extends Feature
{
	/* FIELDS ******************************************************************/

	
	// The value of the feature
	protected	double[]	value;

	
	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the values of the feature for the recording whose data
	 * was used to construct this object.
	 */
	public double[] getValue()
	{
		return value;
	}


	/**
	 * Sets the values of the feature for the recording whose data
	 * was used to construct this object.
	 */
	public void setValue(double[] new_values)
	{
		value = new_values;
	}


	/**
	 * Returns the name of the feature.
	 */
	public	abstract	String		getName();


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public	abstract	String		getDescription();


	/**
	 * Returns the code number of the feature.
	 */
	public	abstract	String		getCode();
}