/*
 * @(#)PitchedInstrumentsPresentFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package	bodhidharma.midi_parsing.multi_dimensional_features;

import  bodhidharma.midi_parsing.*;

/**
 * Each object of this class calculates the value of a single multi-dimensional feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the values of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class PitchedInstrumentsPresentFeature
	extends FeatureMultiDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to null if the parameter is null.
	 */
	public PitchedInstrumentsPresentFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			value = new double[128];

			for (int instrument = 0; instrument < value.length; instrument++)
			{
				if (recording_info.pitched_instrumentation_frequencies[instrument][0] > 0)
					value[instrument] = 1.0;
				else
					value[instrument] = 0.0;
			}
		}

		else value = null;
	}

	
	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Pitched Instruments Present");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Which pitched General MIDI Instruments are present.\n" +
		                  "There is one entry for each instrument, which is set\n" +
		                  "to 1.0 if there is at least one Note On in the recording\n" +
		                  "corresponding to the instrument and to 0.0 if there is not.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("I-1");
	}
}