/*
 * @(#)UnpitchedInstrumentsPresentFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package	bodhidharma.midi_parsing.multi_dimensional_features;

import  bodhidharma.midi_parsing.*;

/**
 * Each object of this class calculates the value of a single multi-dimensional feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the values of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class UnpitchedInstrumentsPresentFeature
	extends FeatureMultiDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to null if the parameter is null.
	 */
	public UnpitchedInstrumentsPresentFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			value = new double[47];

			for (int instrument = 35; instrument < 82; instrument++)
			{
				if (recording_info.non_pitched_instrumentation_frequencies[instrument] > 0)
					value[instrument - 35] = 1.0;
				else
					value[instrument - 35] = 0.0;
			}
		}

		else value = null;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Unpitched Instruments Present");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Which unpitched MIDI Percussion Key Map instruments are present.\n" +
		                  "There is one entry for each instrument, which is set\n" +
		                  "to 1.0 if there is at least one Note On in the recording\n" +
		                  "corresponding to the instrument and to 0.0 if there is not.\n" +
		                  "\nIt should be noted that only instruments 35 to 81 are\n" +
		                  "included here, as they are the ones that meet the official\n" +
		                  "standard. They are numbered in this array from 0 to 46.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("I-2");
	}
}