/*
 * @(#)AverageNoteToNoteDynamicsChangeFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class AverageNoteToNoteDynamicsChangeFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public AverageNoteToNoteDynamicsChangeFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Find the total number of intervals between notes on each channel
			int number_changes = 0;
			for (int i = 0; i < recording_info.note_loudnesses.length; i++)
				if (recording_info.note_loudnesses[i].length > 1)
					number_changes += recording_info.note_loudnesses[i].length;

			// Find all of the loudness intervals
			double[] loudness_intervals = new double[number_changes];
			int count = 0;
			for (int i = 0; i < recording_info.note_loudnesses.length; i++)
				if (recording_info.note_loudnesses[i].length > 1)
					for (int j = 1; j < recording_info.note_loudnesses[i].length; j++)
					{
						loudness_intervals[count] = (double)
							Math.abs( recording_info.note_loudnesses[i][j] -
							          recording_info.note_loudnesses[i][j-1] );
						count++;
					}

			// Calculate the average
			value = bodhidharma.utilities.Statistics.getAverage(loudness_intervals);
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Average Note To Note Dynamics Change");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Average change of loudness from one note to the next note in\n" +
		                  "the same channel.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("D-4");
	}
}