/*
 * @(#)ChangesOfMeterFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma.midi_parsing.*;
import java.util.LinkedList;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class ChangesOfMeterFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public ChangesOfMeterFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Default to no
			value = 0.0;

			// If time signature specified
			if (((LinkedList) recording_info.meta_data[1]).size() != 0)
			{
				// Convert data types
				Object[] numerators_objects = ((LinkedList) recording_info.meta_data[1]).toArray();
				int[] numerators = new int[numerators_objects.length];
				for (int i = 0; i < numerators.length; i++)
					numerators[i] = ((Integer) numerators_objects[i]).intValue();
				
				// Find if changes
				if (numerators.length > 1)
					value = 1.0;
			}
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Changes of Meter");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Set to 1 if the time signature is changed one or more times\n" +
		                  "during the recording.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("R-35");
	}
}