/*
 * @(#)DirectionOfMotionFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;
import java.util.LinkedList.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class DirectionOfMotionFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public DirectionOfMotionFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			int ups = 0;
			int downs = 0;
			for (int chan = 0; chan < recording_info.melody_list.length; chan++)
			{
				if (chan != (10 - 1))
				{
					// Convert to array
					Object[] list_contents = recording_info.melody_list[chan].toArray();
					int[] intervals = new int[list_contents.length];
					for (int i = 0; i < intervals.length; i++)
						intervals[i] = ((Integer) list_contents[i]).intValue();

					// Find amount of upper and downward motion
					for (int i = 0; i < intervals.length; i++)
					{
						if (intervals[i] > 0)
							ups++;
						else if (intervals[i] < 0)
							downs++;
					}
				}
			}

			// Calculate the value
			value = (double) ups / ((double) (ups + downs));
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Direction of Motion");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Fraction of melodic intervals that are rising rather than falling.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("M-17");
	}
}