/*
 * @(#)MinimumNoteDurationFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;
import java.util.LinkedList.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class MinimumNoteDurationFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public MinimumNoteDurationFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Put durations in an array
			Object[] durations_obj = recording_info.note_durations.toArray();
			double[] durations = new double[durations_obj.length];
			for (int i = 0; i < durations.length; i++)
				durations[i] = ((Double) durations_obj[i]).doubleValue(); 

			// Calculate value
			int index = bodhidharma.utilities.Statistics.getIndexOfSmallest(durations);
			value = durations[index];
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Minimum Note Duration");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Duration of the shortest note (in seconds).");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("R-20");
	}
}