/*
 * @(#)NumberOfUnpitchedInstrumentsFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class NumberOfUnpitchedInstrumentsFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public NumberOfUnpitchedInstrumentsFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			int total_number_instruments_played = 0;
			for (int instrument = 35; instrument < 82; instrument++)
				if (recording_info.non_pitched_instrumentation_frequencies[instrument] > 0)
					total_number_instruments_played++;

			value = (double) total_number_instruments_played;
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Number of Unpitched Instruments");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Number of distinct MIDI Percussion Key Map patches that\n" +
		                  "were used to play at least one note.\n" +
		                  "\nIt should be noted that only instruments 35 to 81 are\n" +
		                  "included here, as they are the ones that are included in\n" +
		                  "the official standard.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("I-9");
	}
}