/*
 * @(#)PercussionPrevalenceFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import  bodhidharma.midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class PercussionPrevalenceFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTORS ************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public PercussionPrevalenceFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			int total_number_note_ons = 0;
			for (int channel = 0; channel < recording_info.channel_statistics.length; channel++)
				total_number_note_ons += recording_info.channel_statistics[channel][0];
				
			int number_unpitched_note_ons =  recording_info.channel_statistics[10 - 1][0];
		
			value = (double) number_unpitched_note_ons / (double) total_number_note_ons;
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Percussion Prevalence");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Total number of Note Ons corresponding to unpitched percussion\n " +
		                  "instruments divided by total number of Note Ons in the recording.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("I-10");
	}
}