/*
 * @(#)PitchVarietyFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class PitchVarietyFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public PitchVarietyFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Find the number of pitches
			int count = 0;
			for (int bin = 0; bin < recording_info.basic_pitch_histogram.length; bin++)
				if (recording_info.basic_pitch_histogram[bin] > 0.00001)
					count++;

			// Calculate the value
			value = (double) count;
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Pitch Variety");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Number of pitches used at least once.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("P-8");
	}
}