/*
 * @(#)RangeOfHighestLineFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class RangeOfHighestLineFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public RangeOfHighestLineFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Find the channel with the highest average pitch
			int max_so_far = 0;
			int highest_chan = 0;
			for (int chan = 0; chan < recording_info.channel_statistics.length; chan++)
				if (recording_info.channel_statistics[chan][6] != 0 && chan != (10 - 1))
					if (recording_info.channel_statistics[chan][6] > max_so_far)
					{
						max_so_far = recording_info.channel_statistics[chan][6];
						highest_chan = chan;
					}

			// Find the range of the highest channel
			double range_of_highest = (double) (recording_info.channel_statistics[highest_chan][5] -
			                                    recording_info.channel_statistics[highest_chan][4]);

			// Finde the overall range
			int lowest = 127;
			int highest = 0;
			for (int chan = 0; chan < recording_info.channel_statistics.length; chan++)
				if (recording_info.channel_statistics[chan][0] != 0 && chan != (10 - 1))
				{
					if (recording_info.channel_statistics[chan][4] < lowest)
						lowest = recording_info.channel_statistics[chan][4];
					if (recording_info.channel_statistics[chan][5] > highest)
						highest = recording_info.channel_statistics[chan][5];
				}

			// Set value
			value = range_of_highest / ((double) (highest - lowest));
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Range of Highest Line");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Difference between the highest note and the lowest note played in the\n" +
		                  "channel with the highest average pitch divided by the difference between\n" +
		                  "the highest note and the lowest note in the piece.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("T-12");
	}
}