/*
 * @(#)RelativeRangeOfLoudestVoiceFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class RelativeRangeOfLoudestVoiceFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public RelativeRangeOfLoudestVoiceFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Find the loudest channel
			int max_so_far = 0;
			int loudest_chan = 0;
			for (int chan = 0; chan < recording_info.channel_statistics.length; chan++)
				if (recording_info.channel_statistics[chan][0] != 0 && chan != (10 - 1))
					if (recording_info.channel_statistics[chan][2] > max_so_far)
					{
						max_so_far = recording_info.channel_statistics[chan][2];
						loudest_chan = chan;
					}

			// Find the range of the loudest channel
			double loudest_range = (double) (recording_info.channel_statistics[loudest_chan][5] -
			                                 recording_info.channel_statistics[loudest_chan][4]);

			// Finde the overall range
			int lowest = 127;
			int highest = 0;
			for (int chan = 0; chan < recording_info.channel_statistics.length; chan++)
				if (recording_info.channel_statistics[chan][0] != 0 && chan != (10 - 1))
				{
					if (recording_info.channel_statistics[chan][4] < lowest)
						lowest = recording_info.channel_statistics[chan][4];
					if (recording_info.channel_statistics[chan][5] > highest)
						highest = recording_info.channel_statistics[chan][5];
				}

			// Set value
			value = loudest_range / ((double) (highest - lowest));
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Relative Range of Loudest Voice");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Difference between the highest note and the lowest note played in\n" +
		                  "the channel with the highest average loudness divided by the difference\n" +
						  "between the highest note and the lowest note overall in the piece.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("T-10");
	}
}