/*
 * @(#)RelativeStrengthOfTopPitchesFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class RelativeStrengthOfTopPitchesFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public RelativeStrengthOfTopPitchesFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Find the highest bin
			int max_index = bodhidharma.utilities.Statistics.getIndexOfLargest(recording_info.basic_pitch_histogram);
			
			// Find the second highest bin
			double second_max = 0;
			int second_max_index = 0;
			for (int bin = 0; bin < recording_info.basic_pitch_histogram.length; bin++)
				if (recording_info.basic_pitch_histogram[bin] > second_max &&
				    bin != max_index)
				{
					second_max = recording_info.basic_pitch_histogram[bin];
					second_max_index = bin;
				}

			// Calculate the value
			value = recording_info.basic_pitch_histogram[second_max_index] /
			        recording_info.basic_pitch_histogram[max_index];
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Relative Strength of Top Pitches");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("The frequency of the 2nd most common pitch divided by\n" +
		                  "the frequency of the most common pitch.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("P-3");
	}
}