/*
 * @(#)RhythmicVariabilityFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class RhythmicVariabilityFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public RhythmicVariabilityFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Make the reduced histogram
			double[] reduced_histogram = new double[recording_info.rhythmic_histogram.length - 40];
			for (int i = 0; i < reduced_histogram.length; i++)
				reduced_histogram[i] = recording_info.rhythmic_histogram[i + 40];


			// Calculate the value
			value = bodhidharma.utilities.Statistics.getStandardDeviation(reduced_histogram);
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Rhythmic Variability");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Standard deviation of the bin values (except the first 40 empty ones).");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("R-13");
	}
}