/*
 * @(#)VariationOfDynamicsFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class VariationOfDynamicsFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public VariationOfDynamicsFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			double[] loudnesses = new double[recording_info.total_number_notes];
			int count = 0;
			for (int i = 0; i < recording_info.note_loudnesses.length; i++)
				for (int j = 0; j < recording_info.note_loudnesses[i].length; j++)
				{
					loudnesses[count] = (double) recording_info.note_loudnesses[i][j];
					count++;
				}
			
			value = bodhidharma.utilities.Statistics.getStandardDeviation(loudnesses);
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Variation of Dynamics");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Standard deviation of loudness levels of all notes.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("D-2");
	}
}