/*
 * @(#)VoiceEqualityDynamicsFeature.java	1.0 01/06/04
 *
 * McGill University
 */

package bodhidharma.midi_parsing.one_dimensional_features;

import bodhidharma. midi_parsing.*;

/**
 * Each object of this class calculates the value of a single 1-D feature
 * (described in the <code>getDescription</code> method) and stores it.
 *
 * <p>The constructor takes in an intermediate representation of a recording
 * and derives the value of the feature from it.
 *
 * <p>The <code>getName,</code> <code>getDescription,</code> and <code>getCode</code>
 * methods can be called to get information identifying the feature.
 *
 * @author Cory McKay
 */
public class VoiceEqualityDynamicsFeature
	extends FeatureOneDimensional
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Take in the intermediate representations of a MIDI file and generate the feature
	 * value based on them. Sets the feature value to -1 if the parameter is null.
	 */
	public VoiceEqualityDynamicsFeature(MIDIIntermediateRepresentations recording_info)
	{
		if (recording_info != null)
		{
			// Find the number of channels with no note ons
			int silent_count = 0;
			for (int chan = 0; chan < recording_info.channel_statistics.length; chan++)
				if (recording_info.channel_statistics[chan][0] == 0)
					silent_count++;

			// Store the number of note ons in each channel with note ons
			double[] dynamics = new double[recording_info.channel_statistics.length - silent_count];
			int count = 0;
			for (int chan = 0; chan < recording_info.channel_statistics.length; chan++)
				if (recording_info.channel_statistics[chan][0] != 0)
				{
					dynamics[count] = (double) recording_info.channel_statistics[chan][2];
					count++;
				}

			// Calculate the standard deviation
			value = bodhidharma.utilities.Statistics.getStandardDeviation(dynamics);
		}

		else value = -1.0;
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns the name of the feature.
	 */
	public String getName()
	{
		return new String("Voice Equality - Dynamics");
	}


	/**
	 * Returns a sentence or two describing the feature.
	 */
	public String getDescription()
	{
		return new String("Standard deviation of the average volume of notes in each channel that\n" +
		                  "contains at least one note.");
	}


	/**
	 * Returns the code number of the feature.
	 */
	public String getCode()
	{
		return new String("T-6");
	}
}