/*
 * @(#)FileMethods.java	1.2.2 07/15/05
 *
 * McGill Univarsity
 */

package bodhidharma.utilities;

import java.io.*;
import java.util.LinkedList;
import java.util.StringTokenizer;

/**
 * A holder class for static methods relating to files.
 *
 * @author	Cory McKay
 */
public class FileMethods 
{
	/**
	 * Copies the contents of one file to another.
	 * Throws an exception if the destination file already exists
	 * or if the original file does not exist.
	 *
	 * @param	original	The name of the file to be copied.
	 * @param	destination	The name of the file to be copied to.
	 */
	public static void copyFile(String original, String destination)
		throws Exception
	{
		File original_file = new File(original);
		File destination_file = new File(destination);
		if (!original_file.exists())
			throw new Exception("File with path " + original + " does not exist.");
		if (destination_file.exists())
			throw new Exception("File with path " + destination + " already exists.");
		FileReader in = new FileReader(original_file);
		FileWriter out = new FileWriter(destination_file);
		int c;
		while ((c = in.read()) != -1)
			out.write(c);
		in.close();
		out.close();
    }


	/**
	 * Reads in a tab delimited text file and converts it into a 2-D
	 * String array whose first indice refers to the line number and the
	 * second refers to the token (as separated by tabs).
	 *
	 * @param	tab_del_file	The path of the text file to convert.
	 * @return					The parsed results.
	 * @throws					Throws an exception if a problem occurs.
	 */
	public static String[][] tokenizeTabDelFile(String tab_del_file)
		throws Exception
	{
		// Throw an exception if the file does not exist.
		if (!(new File(tab_del_file)).exists())
			throw new Exception("File " + tab_del_file + " does not exist.");

		// Throw an exception if the file is not a file.
		if (!(new File(tab_del_file)).isFile())
			throw new Exception("File " + tab_del_file + " is not actually a file.");

		// Read in the file
		BufferedReader reader = new BufferedReader(new FileReader(tab_del_file)); 

		// Tokenize the file and break it into a list of lines
		LinkedList<String[]> lines = new LinkedList<String[]>();
		String this_line;
		while ((this_line = reader.readLine()) != null) 
		{
			StringTokenizer tokenizer = new StringTokenizer(this_line, "\t");
			String[] this_array = new String[tokenizer.countTokens()];
			for (int tok = 0; tok < this_array.length; tok++)
				this_array[tok] = tokenizer.nextToken();

			// Deal with case where genre is ommitted
			if (this_array.length == 1)
			{
				String[] new_array = new String[2];
				new_array[0] = this_array[0];
				new_array[1] = "Unknown";
				this_array = new_array;
			}

			lines.add(this_array);
		}

		// Prepare an array holding the contents of each line
		String[][] file_contents = new String[lines.size()][];
		for (int i = 0; i < file_contents.length; i++)
			file_contents[i] = (String[]) lines.get(i);

		// Return the results
		return file_contents;
	}
}