/*
 * @(#)NonEditableTableModel.java	1.1 06/25/04
 *
 * McGill Univarsity
 */

package bodhidharma.utilities;

import javax.swing.table.DefaultTableModel;

/**
 * A table model that provides a method to fill a table row by row
 * and makes all cells non-editable.
 *
 * @author Cory McKay
 * @see DefaultTableModel
 * @see JTable
 */
 public class NonEditableTableModel
	extends DefaultTableModel
{
	/* CONSTRUCTOR *************************************************************/


	/**
	 * Same constructor as <code>DefaultTableModel</code>.
	 */
	public NonEditableTableModel(Object[] columnNames, int rows)
	{
		super(columnNames, rows);
	}


	/* PUBLIC METHODS **********************************************************/


	/**
	 * Returns false for all cells
	 */
	public boolean isCellEditable(int row, int column)
	{
		return false;
	}


	/**
	 * Deletes everything in the table and then fills it up one row at a time
	 * based on the given 2-D String array.
	 *
	 * <p>The <i>data</i> parameter contains the contents to put
	 * in the table. The first indice indicates the row and the second indicates
	 * the column.
	 *
	 * @param	data	Data to place in the table.
	 */
	public void fillTable(String[][] data)
	{
		// Remove the contents of the table
		clearTable();

		// Populate each row one by one
		for (int i = 0; i < data.length; i++)
		{
			// Populate a row of the column
			Object[] row_contents = new Object[data[i].length];
			for (int j = 0; j < row_contents.length; j++)
				row_contents[j] = data[i][j];

			// Add the row
			addRow(row_contents);
		}
	}


	/* PRIVATE METHODS *********************************************************/

	
	/**
	 * Removes all contents of the table.
	 */
	private void clearTable()
	// Remove all data on the table
	{
		while (getRowCount() != 0)
		{
			removeRow(0);
		}
	}
}